<?php

namespace Drupal\choices;

use Drupal\choices\Form\ConfigForm;
use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Provides a Choices.js element callback.
 */
class ChoicesCallbacks implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['preRender'];
  }

  /**
   * Pre-render handler for select elements.
   */
  public static function preRender($element) {
    $attached = &$element['#attached'];
    $attached['drupalSettings']['choices'] = [];
    // Load Choices.js if applicable.
    if (static::isApplicable()) {
      $cssSelector = \Drupal::config('choices.settings')->get('css_selector');
      $configurationOptions = \Drupal::config('choices.settings')->get('configuration_options');
      $attached['library'][] = 'choices/choices';
      // Replace multiple spaces and newlines with a comma and single space:
      $attached['drupalSettings']['choices']['cssSelector'] = trim(preg_replace('/\s\s+/', ', ', $cssSelector));
      $attached['drupalSettings']['choices']['configurationOptions'] = $configurationOptions;
    }
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected static function isApplicable() {
    $include = \Drupal::config('choices.settings')->get('include');
    if ($include === ConfigForm::CHOICES_INCLUDE_EVERYWHERE) {
      return TRUE;
    }

    $isAdminRoute = \Drupal::service('router.admin_context')->isAdminRoute();
    switch ($include) {
      case ConfigForm::CHOICES_INCLUDE_ADMIN:
        return $isAdminRoute;

      case ConfigForm::CHOICES_INCLUDE_NO_ADMIN:
        return !$isAdminRoute;

      default:
        return TRUE;
    }
  }

}
